[Pkg-owncloud-commits] [owncloud-client] 33/69: NetworkJobs: Improve timeout handling and increase timeout by 5 sec

Sandro Knauß hefee-guest at moszumanska.debian.org
Fri Nov 7 19:41:08 UTC 2014


This is an automated email from the git hooks/post-receive script.

hefee-guest pushed a commit to branch master
in repository owncloud-client.

commit cf6219bb6fd5cd5e94122e0b3a8966b3a3138805
Author: Markus Goetz <markus at woboq.com>
Date:   Thu Oct 30 11:54:58 2014 +0100

    NetworkJobs: Improve timeout handling and increase timeout by 5 sec
---
 src/mirall/networkjobs.cpp | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/src/mirall/networkjobs.cpp b/src/mirall/networkjobs.cpp
index d9c61ee..e5780df 100644
--- a/src/mirall/networkjobs.cpp
+++ b/src/mirall/networkjobs.cpp
@@ -51,7 +51,7 @@ AbstractNetworkJob::AbstractNetworkJob(Account *account, const QString &path, QO
 {
     _timer.setSingleShot(true);
     if (!AbstractNetworkJob::preOc7WasDetected) {
-        _timer.setInterval(10*1000); // default to 10 seconds.
+        _timer.setInterval(15*1000); // default to 15 seconds.
     } else {
         qDebug() << "Pre-oc7 server detected, adjusting timeout values";
         _timer.setInterval(60*1000); // long PROPFINDs in oc6 might take too long
@@ -104,6 +104,12 @@ void AbstractNetworkJob::setPath(const QString &path)
 void AbstractNetworkJob::setupConnections(QNetworkReply *reply)
 {
     connect(reply, SIGNAL(finished()), SLOT(slotFinished()));
+#if QT_VERSION >= QT_VERSION_CHECK(5, 1, 0)
+    connect(reply, SIGNAL(encrypted()), SIGNAL(networkActivity()));
+#endif
+    connect(reply->manager(), SIGNAL(proxyAuthenticationRequired(QNetworkProxy,QAuthenticator*)), SIGNAL(networkActivity()));
+    connect(reply, SIGNAL(sslErrors(QList<QSslError>)), SIGNAL(networkActivity()));
+    connect(reply, SIGNAL(metaDataChanged()), SIGNAL(networkActivity()));
     connect(reply, SIGNAL(downloadProgress(qint64,qint64)), SIGNAL(networkActivity()));
     connect(reply, SIGNAL(uploadProgress(qint64,qint64)), SIGNAL(networkActivity()));
 }

-- 
Alioth's /usr/local/bin/git-commit-notice on /srv/git.debian.org/git/pkg-owncloud/owncloud-client.git



More information about the Pkg-owncloud-commits mailing list